@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 from __future__ import annotations
-from unittest import TestCase, main
+
+from unittest import TestCase
+from unittest import main
 
 
 class Test(TestCase):
