@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
 from __future__ import annotations
-from unittest import TestCase, main
 
-from PyR3.shortcut.context import Objects, wipeScenes
+from unittest import TestCase
+from unittest import main
+
+from PyR3.shortcut.context import Objects
+from PyR3.shortcut.context import wipeScenes
 from PyR3.shortcut.edit import Edit
-from PyR3.shortcut.mesh import fromPyData, join, addCube
-from PyR3.shortcut.io import export_blend
+from PyR3.shortcut.io import export_to
+from PyR3.shortcut.mesh import addCube
+from PyR3.shortcut.mesh import fromPyData
+from PyR3.shortcut.mesh import join
 
 
 class TestMeshModule(TestCase):
@@ -18,7 +23,7 @@ class TestMeshModule(TestCase):
             self.assertEqual(len(edit.vertices()), 3)
             self.assertEqual(len(edit.edges()), 3)
             self.assertEqual(len(edit.faces()), 1)
-        export_blend(filepath="./tests/.temp/fromPyData.blend")
+        export_to(filepath="./tests/.temp/fromPyData.blend")
 
     def test_join(self):
         wipeScenes()
